==> speech-analytic-testing_0.16.1_database.tar.gz: database/mssql/procedures/GetEvaluationPlansSummary.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[GetEvaluationPlansSummary] (
	@Instance Varchar(50) = NULL,
	@IdAuditor Varchar(50) = NULL,
	@IdAgent Varchar(50) = NULL,
	@Campaigns VARCHAR(MAX) = NULL,
	@EndDate Varchar(50) = NULL,
	@EvaluationFormats Varchar(MAX) = NULL,
	@Modalities Varchar(MAX) = NULL,
	@Completed Bit = NULL
)
AS
BEGIN
	SET NOCOUNT ON
	
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';
	DECLARE @SQL_SELECT_2 VARCHAR(MAX) = '';
	DECLARE @SQL_FROM_2 VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER_2 VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA_2 VARCHAR(MAX) = '';

	SET @SQL_SELECT_1 += '
		SELECT EP.[ID]																	''id'',
				EP.[Modality]															''modality'',
				EP.[DateFin]															''dateFin'',
				EP.[CreatedDate]														''createdDate'',
				EP.[IdEvaluationFormat]													''idEvaluationFormat'',
				EP.[Description]														''description'',
				COUNT(CASE AEP.Completed WHEN 0 THEN 1 ELSE NULL END)					''pendingInteractionCount'',
				COUNT(AEP.Completed)													''completedCount'',
				SUM(AEP.InteractionDuration)											''interactionTimeSum'',
				SUM(CASE AEP.Completed WHEN 0 THEN AEP.InteractionDuration ELSE 0 END)	''pendingInteractionTimeSum'' ';

	SET @SQL_FROM += '
			FROM [EvaluationPlan] EP (NOLOCK)
			LEFT JOIN [AuditorEvaluationPlan] AEP (NOLOCK)
				ON (AEP.[Instance] = ''' + @Instance + ''' ';

	IF (@IdAuditor IS NOT NULL AND @IdAuditor <> '') SET @SQL_FROM += 'AND AEP.[IdAuditor] = ''' + @IdAuditor + ''' '

	IF (@IdAgent IS NOT NULL AND @IdAgent <> '') SET @SQL_FROM += 'AND AEP.[IdAgent] = ''' + @IdAgent + ''' '

	SET @SQL_FROM += ')';

	SET @SQL_FILTER += '
			WHERE EP.[Instance] = ''' + @Instance + '''
				AND AEP.[IdEvaluationPlan] = EP.[ID]
				AND EP.[DateFin] <= ''' + @EndDate + ''' 
				AND EP.[Enabled] = 1 ';

	IF (@Campaigns IS NOT NULL AND @Campaigns <> '')
	BEGIN
		SET @SQL_FILTER += '
				AND EP.[IdEvaluationFormat] IN ( 
					SELECT CEF.[IdEvaluationFormat] FROM CampaignEvaluationFormat CEF (NOLOCK)
						WHERE CEF.[Instance] = ''' + @Instance + '''
							AND CEF.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','',''))) '
	END;

	IF (@EvaluationFormats IS NOT NULL AND @EvaluationFormats <> '') SET @SQL_FILTER += 'AND EP.[IdEvaluationFormat] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationFormats + ''','','')) ';
	IF (@Modalities IS NOT NULL AND @Modalities <> '') SET @SQL_FILTER += 'AND EP.[Modality] IN (SELECT Value FROM [dbo].[split](''' + @Modalities + ''','','')) ';
	
	IF (@Completed = 1)
	BEGIN
		SET @SQL_FILTER += 'AND AEP.[Completed] = 1 ';
		SET @SQL_FILTER_2 = ' ';	
	END
	ELSE 
	BEGIN
		SET @SQL_FILTER += 'AND AEP.[Completed] = 0 ';
		SET @SQL_FILTER_2 = 'WHERE X.[pendingInteractionCount] > 0 ';
	END;
	

	SET @SQL_EXTRA += '
			GROUP BY EP.[ID],
						EP.[Modality],
						EP.[DateFin],
						EP.[CreatedDate],
						EP.[IdEvaluationFormat],
						EP.[Description]';

	SET @SQL_SELECT_1 += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA;

	--SET @SQL_SELECT_1 = 'SELECT * FROM (' + @SQL_SELECT_1 + ') AS X WHERE X.[pendingInteractionCount] > 0 ORDER BY X.[Description] ASC; ';
	SET @SQL_SELECT_2 = 'SELECT * ';
	SET @SQL_FROM_2 = 'FROM (' + @SQL_SELECT_1 + ') AS X ';
	-- @SQL_FILTER_2 YA FUE DEFINIDO SEGUN SE BUSCAN LAS YA EVALUADAS O NO EVALUADAS
	SET @SQL_EXTRA_2 = 'ORDER BY X.[Description] ASC;';

	SET @SQL_SELECT_2 += @SQL_FROM_2 + @SQL_FILTER_2 + @SQL_EXTRA_2;

	--select @SQL_SELECT_2;
	EXEC (@SQL_SELECT_2);
	
	SET NOCOUNT OFF
	
END;
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_1.5.0_database.tar.gz: database/mssql/procedures/GetEvaluationPlansSummary.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[GetEvaluationPlansSummary] (
	@VCC Varchar(50) = NULL,
	@IdAuditor Varchar(50) = NULL,
	@IdAgent Varchar(50) = NULL,
	@Campaigns VARCHAR(MAX) = NULL,
	@EndDate Varchar(50) = NULL,
	@EvaluationFormats Varchar(MAX) = NULL,
	@Modalities Varchar(MAX) = NULL,
	@Completed Bit = 1
)
AS
BEGIN
	SET NOCOUNT ON
	
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';
	DECLARE @SQL_SELECT_2 VARCHAR(MAX) = '';
	DECLARE @SQL_FROM_2 VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER_2 VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA_2 VARCHAR(MAX) = '';

	SET @SQL_SELECT_1 += '
		SELECT EP.[ID]																	''id'',
				EP.[Modality]															''modality'',
				EP.[DateFin]															''dateFin'',
				EP.[CreatedDate]														''createdDate'',
				EP.[IdEvaluationFormat]													''idEvaluationFormat'',
				EP.[Description]														''description'',
				COUNT(CASE AEP.Completed WHEN 0 THEN 1 ELSE NULL END)					''pendingInteractionCount'',
				COUNT(AEP.Completed)													''completedCount'',
				SUM(AEP.InteractionDuration)											''interactionTimeSum'',
				SUM(CASE AEP.Completed WHEN 0 THEN AEP.InteractionDuration ELSE 0 END)	''pendingInteractionTimeSum'' ';

	SET @SQL_FROM += '
			FROM [EvaluationPlan] EP (NOLOCK)
			LEFT JOIN [AuditorEvaluationPlan] AEP (NOLOCK)
				ON (AEP.[Instance] = ''' + @VCC + ''' ';

	IF (@IdAuditor IS NOT NULL AND @IdAuditor <> '') SET @SQL_FROM += 'AND AEP.[IdAuditor] = ''' + @IdAuditor + ''' '

	IF (@IdAgent IS NOT NULL AND @IdAgent <> '') SET @SQL_FROM += 'AND AEP.[IdAgent] = ''' + @IdAgent + ''' '

	SET @SQL_FROM += ')';

	SET @SQL_FILTER += '
			WHERE EP.[Instance] = ''' + @VCC + '''
				AND AEP.[IdEvaluationPlan] = EP.[ID]
				AND EP.[Enabled] = 1 ';
				
				
    IF (@EndDate IS NOT NULL AND @EndDate <> '')
    BEGIN 
       SET @SQL_FILTER +=' AND EP.[DateFin] <= ''' + @EndDate + ''''
    END

	IF (@Campaigns IS NOT NULL AND @Campaigns <> '')
	BEGIN
		SET @SQL_FILTER += '
				AND EP.[IdEvaluationFormat] IN ( 
					SELECT CEF.[IdEvaluationFormat] FROM CampaignEvaluationFormat CEF (NOLOCK)
						WHERE CEF.[Instance] = ''' + @VCC + '''
							AND CEF.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','',''))) '
	END;

	IF (@EvaluationFormats IS NOT NULL AND @EvaluationFormats <> '') SET @SQL_FILTER += 'AND EP.[IdEvaluationFormat] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationFormats + ''','','')) ';
	IF (@Modalities IS NOT NULL AND @Modalities <> '') SET @SQL_FILTER += 'AND EP.[Modality] IN (SELECT Value FROM [dbo].[split](''' + @Modalities + ''','','')) ';
	
	IF (@Completed = 1)
	BEGIN
		SET @SQL_FILTER += 'AND AEP.[Completed] = 1 ';
		SET @SQL_FILTER_2 = ' ';	
	END
	ELSE 
	BEGIN
		SET @SQL_FILTER += 'AND AEP.[Completed] = 0 ';
		SET @SQL_FILTER_2 = 'WHERE X.[pendingInteractionCount] > 0 ';
	END;
	

	SET @SQL_EXTRA += '
			GROUP BY EP.[ID],
						EP.[Modality],
						EP.[DateFin],
						EP.[CreatedDate],
						EP.[IdEvaluationFormat],
						EP.[Description]';

	SET @SQL_SELECT_1 += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA;

	--SET @SQL_SELECT_1 = 'SELECT * FROM (' + @SQL_SELECT_1 + ') AS X WHERE X.[pendingInteractionCount] > 0 ORDER BY X.[Description] ASC; ';
	SET @SQL_SELECT_2 = 'SELECT * ';
	SET @SQL_FROM_2 = 'FROM (' + @SQL_SELECT_1 + ') AS X ';
	-- @SQL_FILTER_2 YA FUE DEFINIDO SEGUN SE BUSCAN LAS YA EVALUADAS O NO EVALUADAS
	SET @SQL_EXTRA_2 = 'ORDER BY X.[Description] ASC;';

	SET @SQL_SELECT_2 += @SQL_FROM_2 + @SQL_FILTER_2 + @SQL_EXTRA_2;


	EXEC (@SQL_SELECT_2);
	
	SET NOCOUNT OFF
	
END;
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
